#
# spec file for package level-zero
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023 Alessandro de Oliveira Faria (A.K.A CABELO) <cabelo@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           level-zero
Version:        1.20.2
Release:        1.1
Summary:        oneAPI Level Zero Specification Headers and Loader
License:        MIT
URL:            https://github.com/oneapi-src/level-zero
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  opencl-headers

%description
The objective of the oneAPI Level-Zero Application Programming Interface (API)
is to provide direct-to-metal interfaces to offload accelerator devices. Its
programming interface can be tailored to any device needs and can be adapted to
support broader set of languages features such as function pointers, virtual
functions, unified memory, and I/O capabilities.

%package devel
Summary:        The oneAPI Level Zero Specification Headers and Loader development package
Requires:       %{name} = %{version}-%{release}

%description   devel
The %{name}-devel package contains library and header files for developing
applications that use %{name}.

%prep
%autosetup -n level-zero-%{version}

%build
%define __builder ninja
%cmake
%cmake_build

%install
%cmake_install

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license LICENSE
%{_libdir}/libze_loader.so.*
%{_libdir}/libze_validation_layer.so.*
%{_libdir}/libze_tracing_layer.so.*

%files devel
%dir %{_includedir}/level_zero
%{_includedir}/level_zero/*
%{_libdir}/libze_loader.so
%{_libdir}/libze_validation_layer.so
%{_libdir}/libze_tracing_layer.so
%{_libdir}/pkgconfig/libze_loader.pc
%{_libdir}/pkgconfig/level-zero.pc

%changelog
* Mon Feb  3 2025 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 1.20.2:
  * Update to spec 1.12
  * Update to spec v1.12.15
  * Fix to validation layer param checker for extensions
  * Fixed pkg-config files generation
  * fix: potential memory leaks
  * Fix libddi table query code generation
* Sat Jan  4 2025 Eyad Issa <eyadlorenzo@gmail.com>
- Added _service to download files
- Renamed tarball to match convention %%{name}-%%{version}.tar.gz
- Use ninja as cmake builder instead of Make
- Updated to version 1.19.2
  * API Headers, Loader, & Validation Layer based on oneAPI
    Level Zero Specification v1.11.8
* Tue Oct  1 2024 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- update to 1.17.45:
  * Add missing guard around debug message
  * Switch to monotonically increasing patch numbers
  * Fix warning by updating min cmake version to 3.5
  * Add missing guards around debug messages
  * Fix SysMan driver pointers given no sysman env and no
    zesInit (#193)
  * Prevent reinit when zes/ze handles have already been
    retrieved (#192)
  * Proper installation rules
  * Enable testing with ctest
  * Fix reading updated state of the driver_t for checking
    initStatus (#188)
  * Avoid DDI table reinit if
    ZE_ENABLE_LOADER_INTERCEPT=1 (#187)
  * Update spdlog headers (#186)
  * Fix handle translation when ddi table fallback (#185)
  * Split Ze and Zes Drivers and only release
    drivers at close (#184)
  * Fix issues with intercept layer and zesInit/zeInit
    given fallback to passthrough (#183)
  * Fix global teardown of loader handles and check driver
    status in init_driver (#182)
  * Add GPU-legacy1 driver to list of known names on Linux
  * Fix first zeinit to allow for layer checks
* Sun Aug 18 2024 Dirk Müller <dmueller@suse.com>
- update to 1.17.25:
  * Don't exchange zet/zes DDI tables for tracing
  * Fix OpenSSF token permissions warning
  * Rename init functions to avoid confusion with zeInit
  * Add missing ZE_RESULT_ERROR_UNINITIALIZED checks to
    zesDriverGet
  * Fix DriverGet to handle failed drivers and avoid layer init
    during checks
  * Fix layer init with multiple drivers and ensure init for
    instrumentation support
  * Change loader log file location
  * Add update-spec.yml workflow
  * Define FMT_HEADER_ONLY for spdlog inclusion
  * spdlog: Use system library if requested
  * Create scorecard.yml
  * Support for Pluggable Validation Layer Checkers
  * Add NPU Driver to list of known names on linux
  * Correct casting in tracing layer sample code
  * Bundle spdlog headers as part of build vs library build
  * Recognize mutable command list struct types in validation
    layer
  * Update to support v1.9.3 of the L0 Spec
  * Fix Tracing Layer Dynamic Enable Counter
  * Fix loading environment strings
  * Avoid init of Logger unless Enabled by
    ZEL_ENABLE_LOADER_LOGGING
  * fix Logging build to be static linked
  * Fix code Gen scripts for zesInit Only
  * Fix Build using IntelLLVM compiler
  * Installation path fixes
  * Add USE_ASAN cmake flag for address sanitization
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 1.16.1:
  * Fix to spec generated api version defines
  * Update to spec 1.9.1
  * Enable for zesInit to run with zeInit without duplicate init
  * Addressed OpenSSF Token Permissions
  * Fix for missing extension types in the validation layer
  * Added structure for Loader validation testing
* Wed Dec 27 2023 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- Created package level-zero version 1.15.8
  - API Headers, Loader, & Validation Layer based on oneAPI
    Level Zero Specification v1.8.0
  * oneAPI Level Zero API Headers generated from:
  - oneAPI Level Zero v1.8.0 Core API Headers
  - oneAPI Level Zero v1.8.0 Tools API Headers
  - oneAPI Level Zero v1.8.0 Sysman API Headers
  * oneAPI Level Zero Loader v1.15.8
  * oneAPI Level Zero Validation Layer v1.15.8
  * oneAPI Level Zero Tracing Layer v1.15.8
  - Packages Included:
  * level-zero -> Runtime package providing oneAPI
    Level Zero Loader & Validation Layer
  * level-zero-devel -> Development package providing oneAPI Level Zero
    Loader, Validation Layer & API Headers
* Thu Nov  9 2023 Dirk Müller <dmueller@suse.com>
- update to 1.15.1:
  * Update to spec 1.8.0
* Fri Sep  1 2023 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- Created package level-zero version 1.14.0
  - API Headers, Loader, & Validation Layer based on oneAPI
    Level Zero Specification v1.7.8 Contents:
  * oneAPI Level Zero API Headers generated from:
  - oneAPI Level Zero v1.7.8 Core API Headers
  - oneAPI Level Zero v1.7.8 Tools API Headers
  - oneAPI Level Zero v1.7.8 Sysman API Headers
  * oneAPI Level Zero Loader v1.14.0
  * oneAPI Level Zero Validation Layer v1.14.0
  * oneAPI Level Zero Tracing Layer v1.14.0
  - Packages Included:
  * level-zero -> Runtime package providing oneAPI Level Zero
    Loader & Validation Layer
  * level-zero-devel -> Development package providing oneAPI Level Zero
    Loader, Validation Layer & API Headers
* Mon Jul 31 2023 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- Created package level-zero version 1.13.1
  - API Headers, Loader, & Validation Layer based on oneAPI
    Level Zero Specification v1.6.10 Contents:
  * oneAPI Level Zero API Headers generated from:
  - oneAPI Level Zero v1.7.0 Core API Headers
  - oneAPI Level Zero v1.7.0 Tools API Headers
  - oneAPI Level Zero v1.7.0 Sysman API Headers
  * oneAPI Level Zero Loader v1.13.1
  * oneAPI Level Zero Validation Layer v1.13.1
  * oneAPI Level Zero Tracing Layer v1.13.1
  - Packages Included:
  * level-zero -> Runtime package providing oneAPI Level Zero
    Loader & Validation Layer
  * level-zero-devel -> Development package providing oneAPI Level Zero
    Loader, Validation Layer & API Headers
* Mon Jun 12 2023 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- Created package level-zero version 1.12.0
  - API Headers, Loader, & Validation Layer based on oneAPI Level Zero
    Specification v1.6.10 Contents:
  * oneAPI Level Zero API Headers generated from:
  - oneAPI Level Zero v1.6.10 Core API Headers
  - oneAPI Level Zero v1.6.10 Tools API Headers
  - oneAPI Level Zero v1.6.10 Sysman API Headers
  * oneAPI Level Zero Loader v1.12.0
  * oneAPI Level Zero Validation Layer v1.12.0
  * oneAPI Level Zero Tracing Layer v1.12.0
  - Packages Included:
  * level-zero -> Runtime package providing oneAPI Level Zero
    Loader & Validation Layer
  * level-zero-devel -> Development package providing oneAPI
    Level Zero Loader, Validation Layer & API Headers
* Wed Apr 19 2023 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- API Headers, Loader, & Validation Layer based on oneAPI Level Zero
  Specification v1.6.0
- oneAPI Level Zero API Headers generated from:
  * oneAPI Level Zero v1.6.0 Core API Headers
  * oneAPI Level Zero v1.6.0 Tools API Headers
  * neAPI Level Zero v1.6.0 Sysman API Headers
- oneAPI Level Zero Loader v1.10.0
- oneAPI Level Zero Validation Layer v1.10.0
- oneAPI Level Zero Tracing Layer v1.10.0
- Packages Included:
  * level-zero -> Runtime package providing oneAPI Level Zero
    Loader & Validation Layer
  * level-zero-devel -> Development package providing oneAPI Level Zero
    Loader, Validation Layer & API Headers
- Runtime Implementations Supported
  * intel-level-zero-gpu (https://github.com/intel/compute-runtime/releases)
    Minimum required version 21.09.19150
* Tue Jun 28 2022 Alessandro de Oliveira Faria <cabelo@opensuse.org>
- Created package level-zero version 1.8.5
  * Remove RTLD_DEEPBIND from driver dlopen calls
  * Add loader code generation scripts
  * Update to spec 1.4.8 which includes fixes to zes_power_limit_ext_desc_t
